/*
   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include <QObject>

class DKIMManagerAuthenticationServerTest : public QObject
{
    Q_OBJECT
public:
    explicit DKIMManagerAuthenticationServerTest(QObject *parent = nullptr);
    ~DKIMManagerAuthenticationServerTest() override = default;
private Q_SLOTS:
    void shouldHaveDefaultValue();
};

